pub struct DMSCWSServerConfig {
pub addr: String,
pub port: u16,
pub max_connections: usize,
pub heartbeat_interval: u64,
pub heartbeat_timeout: u64,
pub max_message_size: usize,
pub ping_interval: u64,
}Fields
addr: Stringport: u16max_connections: usizeheartbeat_interval: u64heartbeat_timeout: u64max_message_size: usizeping_interval: u64Trait Implementations
Sourceimpl Clone for DMSCWSServerConfig
impl Clone for DMSCWSServerConfig
Sourcefn clone(&self) -> DMSCWSServerConfig
fn clone(&self) -> DMSCWSServerConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DMSCWSServerConfig
impl Debug for DMSCWSServerConfig
Sourceimpl Default for DMSCWSServerConfig
impl Default for DMSCWSServerConfig
Sourceimpl<'py> IntoPyObject<'py> for DMSCWSServerConfig
impl<'py> IntoPyObject<'py> for DMSCWSServerConfig
Sourcetype Target = DMSCWSServerConfig
type Target = DMSCWSServerConfig
The Python output type
Sourcetype Output = Bound<'py, <DMSCWSServerConfig as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <DMSCWSServerConfig as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PartialEq for DMSCWSServerConfig
impl PartialEq for DMSCWSServerConfig
Sourceimpl PyClass for DMSCWSServerConfig
impl PyClass for DMSCWSServerConfig
Sourceimpl PyClassImpl for DMSCWSServerConfig
impl PyClassImpl for DMSCWSServerConfig
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = c"\x00"
const RAW_DOC: &'static CStr = c"\x00"
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<DMSCWSServerConfig>
type ThreadChecker = SendablePyClass<DMSCWSServerConfig>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyClassNewTextSignature for DMSCWSServerConfig
impl PyClassNewTextSignature for DMSCWSServerConfig
const TEXT_SIGNATURE: &'static str = "()"
Sourceimpl PyMethods<DMSCWSServerConfig> for PyClassImplCollector<DMSCWSServerConfig>
impl PyMethods<DMSCWSServerConfig> for PyClassImplCollector<DMSCWSServerConfig>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for DMSCWSServerConfig
impl PyTypeInfo for DMSCWSServerConfig
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type.impl DerefToPyAny for DMSCWSServerConfig
impl Eq for DMSCWSServerConfig
impl ExtractPyClassWithClone for DMSCWSServerConfig
impl StructuralPartialEq for DMSCWSServerConfig