pub struct DMSCWSSessionInfo {
pub session_id: String,
pub remote_addr: String,
pub connected_at: u64,
pub messages_sent: u64,
pub messages_received: u64,
pub bytes_sent: u64,
pub bytes_received: u64,
pub is_active: bool,
pub last_heartbeat: u64,
}Fields
session_id: Stringremote_addr: Stringconnected_at: u64messages_sent: u64messages_received: u64bytes_sent: u64bytes_received: u64is_active: boollast_heartbeat: u64Trait Implementations
Sourceimpl Clone for DMSCWSSessionInfo
impl Clone for DMSCWSSessionInfo
Sourcefn clone(&self) -> DMSCWSSessionInfo
fn clone(&self) -> DMSCWSSessionInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DMSCWSSessionInfo
impl Debug for DMSCWSSessionInfo
Sourceimpl Default for DMSCWSSessionInfo
impl Default for DMSCWSSessionInfo
Sourceimpl<'py> IntoPyObject<'py> for DMSCWSSessionInfo
impl<'py> IntoPyObject<'py> for DMSCWSSessionInfo
Sourcetype Target = DMSCWSSessionInfo
type Target = DMSCWSSessionInfo
The Python output type
Sourcetype Output = Bound<'py, <DMSCWSSessionInfo as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <DMSCWSSessionInfo as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for DMSCWSSessionInfo
impl PyClass for DMSCWSSessionInfo
Sourceimpl PyClassImpl for DMSCWSSessionInfo
impl PyClassImpl for DMSCWSSessionInfo
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = c"\x00"
const RAW_DOC: &'static CStr = c"\x00"
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<DMSCWSSessionInfo>
type ThreadChecker = SendablePyClass<DMSCWSSessionInfo>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyMethods<DMSCWSSessionInfo> for PyClassImplCollector<DMSCWSSessionInfo>
impl PyMethods<DMSCWSSessionInfo> for PyClassImplCollector<DMSCWSSessionInfo>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for DMSCWSSessionInfo
impl PyTypeInfo for DMSCWSSessionInfo
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type.impl DerefToPyAny for DMSCWSSessionInfo
impl ExtractPyClassWithClone for DMSCWSSessionInfo